=== modified file 'bzrlib/tests/blackbox/__init__.py'
--- bzrlib/tests/blackbox/__init__.py	2007-08-16 18:23:13 +0000
+++ bzrlib/tests/blackbox/__init__.py	2007-09-05 01:54:07 +0000
@@ -103,6 +103,7 @@
                      'bzrlib.tests.blackbox.test_testament',
                      'bzrlib.tests.blackbox.test_too_much',
                      'bzrlib.tests.blackbox.test_uncommit',
+                     'bzrlib.tests.blackbox.test_unknowns',
                      'bzrlib.tests.blackbox.test_update',
                      'bzrlib.tests.blackbox.test_upgrade',
                      'bzrlib.tests.blackbox.test_version',

=== added file 'bzrlib/tests/blackbox/test_unknowns.py'
--- bzrlib/tests/blackbox/test_unknowns.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/blackbox/test_unknowns.py	2007-09-05 01:54:07 +0000
@@ -0,0 +1,46 @@
+# Copyright (C) 2007 Canonical Ltd
+# -*- coding: utf-8 -*-
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+
+"""Black-box tests for 'bzr unknowns', which shows unknown files."""
+
+from bzrlib.tests.blackbox import ExternalBase
+
+class TestUnknowns(ExternalBase):
+
+    def test_unknowns(self):
+        """Test that 'unknown' command reports unknown files"""
+
+        # in empty directory, no unknowns
+        tree = self.make_branch_and_tree('.')
+        self.assertEquals(self.run_bzr('unknowns')[0], '')
+
+        # single unknown file
+        self.build_tree_contents([('a', 'contents of a\n')])
+        self.assertEquals(self.run_bzr('unknowns')[0], 'a\n')
+
+        # multiple unknown files
+        self.build_tree(['b', 'c'])
+        self.assertEquals(self.run_bzr('unknowns')[0], 'a\nb\nc\n')
+
+        # after add, file no longer shown
+        tree.add('a')
+        self.assertEquals(self.run_bzr('unknowns')[0], 'b\nc\n')
+
+        # after all added, none shown
+        tree.add(['b', 'c'])
+        self.assertEquals(self.run_bzr('unknowns')[0], '')

